@@ -22,7 +22,7 @@ export default async function() {
   const page = await context.newPage();
 
   try {
-    await page.goto('https://test.k6.io/', { waitUntil: 'networkidle' });
+    await page.goto('https://quickpizza.grafana.com/test.k6.io/', { waitUntil: 'networkidle' });
 
     const contacts = page.locator('a[href="/contacts.php"]');
     await contacts.dispatchEvent("click");
