@@ -19,9 +19,9 @@ export const options = {
 export default async function() {
   const context = await browser.newContext();
   const page = await context.newPage();
-  
+
   try {
-    await page.goto("https://quickpizza.grafana.com/test.k6.io/flip_coin.php", {
+    await page.goto("https://quickpizza.grafana.com/flip_coin.php", {
       waitUntil: "networkidle",
     })
 
@@ -30,10 +30,10 @@ export default async function() {
     different betting button on the page. If you were to query
     the buttons once and save them as below, you would see an
     error after the initial navigation. Try it!
-  
+
       const heads = page.$("input[value='Bet on heads!']");
       const tails = page.$("input[value='Bet on tails!']");
-  
+
     The Locator API allows you to get a fresh element handle each
     time you use one of the locator methods. And, you can carry a
     locator across frame navigations. Let's create two locators;
