@@ -1,6 +1,7 @@
 import http from "k6/http";
 import exec from 'k6/execution';
-import { check, sleep } from "k6";
+import { sleep } from "k6";
+import { expect } from "https://jslib.k6.io/k6-testing/0.5.0/index.js";
 
 const BASE_URL = __ENV.BASE_URL || 'https://quickpizza.grafana.com';
 
@@ -22,9 +23,7 @@ export const options = {
 
 export function setup() {
   let res = http.get(BASE_URL);
-  if (res.status !== 200) {
-    exec.test.abort(`Got unexpected status code ${res.status} when trying to setup. Exiting.`);
-  }
+  expect(res.status, `Got unexpected status code ${res.status} when trying to setup. Exiting.`).toBe(200);
 }
 
 export default function() {
@@ -44,7 +43,7 @@ export default function() {
     },
   });
 
-  check(res, { "status is 200": (res) => res.status === 200 });
+  expect.soft(res.status).toBe(200);
   console.log(res.json().pizza.name + " (" + res.json().pizza.ingredients.length + " ingredients)");
   sleep(1);
 }
