@@ -1,14 +1,26 @@
 package browser
 
 import (
+	"context"
 	"fmt"
 
 	"github.com/grafana/sobek"
+	"github.com/mstoykov/k6-taskqueue-lib/taskqueue"
 
 	"go.k6.io/k6/internal/js/modules/k6/browser/common"
 	"go.k6.io/k6/internal/js/modules/k6/browser/k6ext"
 )
 
+func cancelableTaskQueue(ctx context.Context, registerCallback func() func(func() error)) *taskqueue.TaskQueue {
+	tq := taskqueue.New(registerCallback)
+
+	go func() {
+		<-ctx.Done()
+		tq.Close()
+	}()
+	return tq
+}
+
 // mapFrame to the JS module.
 //
 //nolint:funlen,gocognit,cyclop
@@ -382,18 +394,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			}), nil
 		},
 		"waitForNavigation": func(opts sobek.Value) (*sobek.Promise, error) {
-			popts := common.NewFrameWaitForNavigationOptions(f.Timeout())
-			if err := popts.Parse(vu.Context(), opts); err != nil {
-				return nil, fmt.Errorf("parsing frame wait for navigation options: %w", err)
-			}
-
-			return k6ext.Promise(vu.Context(), func() (result any, reason error) {
-				resp, err := f.WaitForNavigation(popts)
-				if err != nil {
-					return nil, err //nolint:wrapcheck
-				}
-				return mapResponse(vu, resp), nil
-			}), nil
+			return waitForNavigationBodyImpl(vu, f, opts)
 		},
 		"waitForSelector": func(selector string, opts sobek.Value) (*sobek.Promise, error) {
 			popts := common.NewFrameWaitForSelectorOptions(f.Timeout())
@@ -415,6 +416,9 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, nil
 			})
 		},
+		"waitForURL": func(url sobek.Value, opts sobek.Value) (*sobek.Promise, error) {
+			return waitForURLBodyImpl(vu, f, url, opts)
+		},
 	}
 	maps["$"] = func(selector string) *sobek.Promise {
 		return k6ext.Promise(vu.Context(), func() (any, error) {
