@@ -318,6 +318,13 @@ type pageAPI interface { //nolint:interfacebloat
 	Focus(selector string, opts sobek.Value) error
 	Frames() []*common.Frame
 	GetAttribute(selector string, name string, opts sobek.Value) (string, bool, error)
+	GetByRole(role string, opts *common.GetByRoleOptions) *common.Locator
+	GetByAltText(alt string, opts *common.GetByBaseOptions) *common.Locator
+	GetByLabel(label string, opts *common.GetByBaseOptions) *common.Locator
+	GetByPlaceholder(placeholder string, opts *common.GetByBaseOptions) *common.Locator
+	GetByTitle(title string, opts *common.GetByBaseOptions) *common.Locator
+	GetByTestId(testID string) *common.Locator
+	GetByText(text string, opts *common.GetByBaseOptions) *common.Locator
 	GetKeyboard() *common.Keyboard
 	GetMouse() *common.Mouse
 	GetTouchscreen() *common.Touchscreen
@@ -341,6 +348,7 @@ type pageAPI interface { //nolint:interfacebloat
 	Query(selector string) (*common.ElementHandle, error)
 	QueryAll(selector string) ([]*common.ElementHandle, error)
 	Reload(opts sobek.Value) *common.Response
+	Route(path string, handler sobek.Callable)
 	Screenshot(opts sobek.Value) ([]byte, error)
 	SelectOption(selector string, values sobek.Value, opts sobek.Value) ([]string, error)
 	SetChecked(selector string, checked bool, opts sobek.Value) error
@@ -364,6 +372,7 @@ type pageAPI interface { //nolint:interfacebloat
 	WaitForNavigation(opts sobek.Value) (*common.Response, error)
 	WaitForSelector(selector string, opts sobek.Value) (*common.ElementHandle, error)
 	WaitForTimeout(timeout int64)
+	WaitForURL(url string, opts sobek.Value) (*sobek.Promise, error)
 	Workers() []*common.Worker
 }
 
@@ -432,6 +441,7 @@ type frameAPI interface { //nolint:interfacebloat
 	WaitForNavigation(opts sobek.Value) (*common.Response, error)
 	WaitForSelector(selector string, opts sobek.Value) (*common.ElementHandle, error)
 	WaitForTimeout(timeout int64)
+	WaitForURL(url string, opts sobek.Value) (*sobek.Promise, error)
 }
 
 // elementHandleAPI is the interface of an in-page DOM element.
@@ -516,6 +526,7 @@ type responseAPI interface { //nolint:interfacebloat
 
 // locatorAPI represents a way to find element(s) on a page at any moment.
 type locatorAPI interface { //nolint:interfacebloat
+	All() ([]*common.Locator, error)
 	Clear(opts *common.FrameFillOptions) error
 	Click(opts sobek.Value) error
 	Count() (int, error)
