@@ -4,12 +4,15 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"reflect"
 	"time"
 
 	"github.com/grafana/sobek"
+	"github.com/mstoykov/k6-taskqueue-lib/taskqueue"
 
 	"go.k6.io/k6/internal/js/modules/k6/browser/common"
 	"go.k6.io/k6/internal/js/modules/k6/browser/k6ext"
+	k6common "go.k6.io/k6/js/common"
 )
 
 // mapPage to the JS module.
@@ -163,6 +166,69 @@ func mapPage(vu moduleVU, p *common.Page) mapping { //nolint:gocognit,cyclop
 				return s, nil
 			}), nil
 		},
+		"getByRole": func(role sobek.Value, opts sobek.Value) (*sobek.Object, error) {
+			if k6common.IsNullish(role) {
+				return nil, errors.New("missing required argument 'role'")
+			}
+			popts := parseGetByRoleOptions(vu.Context(), opts)
+
+			ml := mapLocator(vu, p.GetByRole(role.String(), popts))
+			return rt.ToValue(ml).ToObject(rt), nil
+		},
+		"getByAltText": func(alt sobek.Value, opts sobek.Value) (*sobek.Object, error) {
+			if k6common.IsNullish(alt) {
+				return nil, errors.New("missing required argument 'altText'")
+			}
+			palt, popts := parseGetByBaseOptions(vu.Context(), alt, false, opts)
+
+			ml := mapLocator(vu, p.GetByAltText(palt, popts))
+			return rt.ToValue(ml).ToObject(rt), nil
+		},
+		"getByLabel": func(label sobek.Value, opts sobek.Value) (*sobek.Object, error) {
+			if k6common.IsNullish(label) {
+				return nil, errors.New("missing required argument 'label'")
+			}
+			plabel, popts := parseGetByBaseOptions(vu.Context(), label, true, opts)
+
+			ml := mapLocator(vu, p.GetByLabel(plabel, popts))
+			return rt.ToValue(ml).ToObject(rt), nil
+		},
+		"getByPlaceholder": func(placeholder sobek.Value, opts sobek.Value) (*sobek.Object, error) {
+			if k6common.IsNullish(placeholder) {
+				return nil, errors.New("missing required argument 'placeholder'")
+			}
+			pplaceholder, popts := parseGetByBaseOptions(vu.Context(), placeholder, false, opts)
+
+			ml := mapLocator(vu, p.GetByPlaceholder(pplaceholder, popts))
+			return rt.ToValue(ml).ToObject(rt), nil
+		},
+		"getByTitle": func(title sobek.Value, opts sobek.Value) (*sobek.Object, error) {
+			if k6common.IsNullish(title) {
+				return nil, errors.New("missing required argument 'title'")
+			}
+			ptitle, popts := parseGetByBaseOptions(vu.Context(), title, false, opts)
+
+			ml := mapLocator(vu, p.GetByTitle(ptitle, popts))
+			return rt.ToValue(ml).ToObject(rt), nil
+		},
+		"getByTestId": func(testID sobek.Value) (*sobek.Object, error) {
+			if k6common.IsNullish(testID) {
+				return nil, errors.New("missing required argument 'testId'")
+			}
+			ptestID := parseStringOrRegex(testID, false)
+
+			ml := mapLocator(vu, p.GetByTestID(ptestID))
+			return rt.ToValue(ml).ToObject(rt), nil
+		},
+		"getByText": func(text sobek.Value, opts sobek.Value) (*sobek.Object, error) {
+			if k6common.IsNullish(text) {
+				return nil, errors.New("missing required argument 'text'")
+			}
+			ptext, popts := parseGetByBaseOptions(vu.Context(), text, true, opts)
+
+			ml := mapLocator(vu, p.GetByText(ptext, popts))
+			return rt.ToValue(ml).ToObject(rt), nil
+		},
 		"goto": func(url string, opts sobek.Value) (*sobek.Promise, error) {
 			gopts := common.NewFrameGotoOptions(
 				p.Referrer(),
@@ -312,6 +378,7 @@ func mapPage(vu moduleVU, p *common.Page) mapping { //nolint:gocognit,cyclop
 				return mapResponse(vu, resp), nil
 			}), nil
 		},
+		"route": mapPageRoute(vu, p),
 		"screenshot": func(opts sobek.Value) (*sobek.Promise, error) {
 			popts := common.NewPageScreenshotOptions()
 			if err := popts.Parse(vu.Context(), opts); err != nil {
@@ -488,18 +555,7 @@ func mapPage(vu moduleVU, p *common.Page) mapping { //nolint:gocognit,cyclop
 			}), nil
 		},
 		"waitForNavigation": func(opts sobek.Value) (*sobek.Promise, error) {
-			popts := common.NewFrameWaitForNavigationOptions(p.Timeout())
-			if err := popts.Parse(vu.Context(), opts); err != nil {
-				return nil, fmt.Errorf("parsing page wait for navigation options: %w", err)
-			}
-
-			return k6ext.Promise(vu.Context(), func() (result any, reason error) {
-				resp, err := p.WaitForNavigation(popts)
-				if err != nil {
-					return nil, err //nolint:wrapcheck
-				}
-				return mapResponse(vu, resp), nil
-			}), nil
+			return waitForNavigationBodyImpl(vu, p, opts)
 		},
 		"waitForSelector": func(selector string, opts sobek.Value) (*sobek.Promise, error) {
 			popts := common.NewFrameWaitForSelectorOptions(p.MainFrame().Timeout())
@@ -521,6 +577,9 @@ func mapPage(vu moduleVU, p *common.Page) mapping { //nolint:gocognit,cyclop
 				return nil, nil
 			})
 		},
+		"waitForURL": func(url sobek.Value, opts sobek.Value) (*sobek.Promise, error) {
+			return waitForURLBodyImpl(vu, p, url, opts)
+		},
 		"workers": func() *sobek.Object {
 			var mws []mapping
 			for _, w := range p.Workers() {
@@ -608,7 +667,7 @@ func mapPageOn(vu moduleVU, p *common.Page) func(common.PageOnEventName, sobek.C
 
 		ctx := vu.Context()
 
-		// Run the the event handler in the task queue to
+		// Run the event handler in the task queue to
 		// ensure that the handler is executed on the event loop.
 		tq := vu.get(ctx, p.TargetID())
 		eventHandler := func(event common.PageOnEvent) error {
@@ -663,6 +722,59 @@ func prepK6BrowserRegExChecker(rt *sobek.Runtime) func() error {
 	}
 }
 
+// injectRegexMatcherScript injects a JavaScript regex checker function into the runtime
+// for URL pattern matching. This handles regex patterns only using JavaScript's regex
+// engine for consistency. It returns a function that can be used to check if a URL
+// matches a given pattern in the JS runtime's eventloop.
+//
+// Do not call this off the main thread (not even from within a promise). The returned
+// JSRegexChecker can be called from off the main thread (i.e. in a new goroutine) since
+// it will queue up the checker on the event loop.
+func injectRegexMatcherScript(
+	ctx context.Context, vu moduleVU, tq *taskqueue.TaskQueue,
+) (common.JSRegexChecker, error) {
+	rt := vu.Runtime()
+
+	err := prepK6BrowserRegExChecker(rt)()
+	if err != nil {
+		return nil, fmt.Errorf("preparing k6 browser regex checker: %w", err)
+	}
+
+	return func(pattern, url string) (bool, error) {
+		var (
+			result bool
+			err    error
+		)
+
+		done := make(chan struct{})
+
+		tq.Queue(func() error {
+			defer close(done)
+
+			// Regex pattern is unquoted string whereas the url needs to be quoted
+			// so that it is treated as a string.
+			js := fmt.Sprintf(`_k6BrowserCheckRegEx(%s, '%s')`, pattern, url)
+
+			val, jsErr := rt.RunString(js)
+			if jsErr != nil {
+				err = fmt.Errorf("evaluating pattern: %w", jsErr)
+				return nil
+			}
+
+			result = val.ToBoolean()
+			return nil
+		})
+
+		select {
+		case <-done:
+		case <-ctx.Done():
+			err = fmt.Errorf("context canceled while evaluating URL pattern")
+		}
+
+		return result, err
+	}, nil
+}
+
 func parseWaitForFunctionArgs(
 	ctx context.Context, timeout time.Duration, pageFunc, opts sobek.Value, gargs ...sobek.Value,
 ) (string, *common.FrameWaitForFunctionOptions, []any, error) {
@@ -680,3 +792,230 @@ func parseWaitForFunctionArgs(
 
 	return js, popts, exportArgs(gargs), nil
 }
+
+// parseStringOrRegex parses a sobek.Value to return either a quoted string if it was a string,
+// or a raw string if it was a JS RegExp object or another type.
+//
+// Some getBy* APIs work with single quotes and some work with double quotes.
+// This inconsistency seems to stem from the injected code copied from
+// Playwright itself.
+//
+// I would prefer not to change the copied injected script code from Playwright
+// so that it is easier to copy over updates/fixes from Playwright when we need
+// to.
+func parseStringOrRegex(v sobek.Value, doubleQuote bool) string {
+	var a string
+	switch v.ExportType() {
+	case reflect.TypeOf(string("")): // text values require quotes
+		if doubleQuote {
+			a = fmt.Sprintf(`"%s"`, v.String())
+		} else {
+			a = fmt.Sprintf("'%s'", v.String())
+		}
+	case reflect.TypeOf(map[string]interface{}(nil)): // JS RegExp
+		a = v.String() // No quotes
+	default: // CSS, numbers or booleans
+		a = v.String() // No quotes
+	}
+	return a
+}
+
+// parseGetByRoleOptions parses the GetByRole options from the Sobek.Value.
+func parseGetByRoleOptions(ctx context.Context, opts sobek.Value) *common.GetByRoleOptions {
+	if !sobekValueExists(opts) {
+		return nil
+	}
+
+	o := &common.GetByRoleOptions{}
+
+	rt := k6ext.Runtime(ctx)
+
+	obj := opts.ToObject(rt)
+	for _, k := range obj.Keys() {
+		switch k {
+		case "checked":
+			val := obj.Get(k).ToBoolean()
+			o.Checked = &val
+		case "disabled":
+			val := obj.Get(k).ToBoolean()
+			o.Disabled = &val
+		case "exact":
+			val := obj.Get(k).ToBoolean()
+			o.Exact = &val
+		case "expanded":
+			val := obj.Get(k).ToBoolean()
+			o.Expanded = &val
+		case "includeHidden":
+			val := obj.Get(k).ToBoolean()
+			o.IncludeHidden = &val
+		case "level":
+			val := obj.Get(k).ToInteger()
+			o.Level = &val
+		case "name":
+			val := parseStringOrRegex(obj.Get(k), false)
+			o.Name = &val
+		case "pressed":
+			val := obj.Get(k).ToBoolean()
+			o.Pressed = &val
+		case "selected":
+			val := obj.Get(k).ToBoolean()
+			o.Selected = &val
+		}
+	}
+
+	return o
+}
+
+// parseGetByBaseOptions parses the options for the GetBy* APIs and the input
+// text/regex.
+func parseGetByBaseOptions(
+	ctx context.Context,
+	input sobek.Value,
+	doubleQuote bool,
+	opts sobek.Value,
+) (string, *common.GetByBaseOptions) {
+	a := parseStringOrRegex(input, doubleQuote)
+
+	if !sobekValueExists(opts) {
+		return a, nil
+	}
+
+	o := &common.GetByBaseOptions{}
+
+	rt := k6ext.Runtime(ctx)
+
+	obj := opts.ToObject(rt)
+	for _, k := range obj.Keys() {
+		if k == "exact" {
+			val := obj.Get(k).ToBoolean()
+			o.Exact = &val
+		}
+	}
+
+	return a, o
+}
+
+// mapPageRoute maps the requested page.route event to the Sobek runtime.
+func mapPageRoute(vu moduleVU, p *common.Page) func(path sobek.Value, handler sobek.Callable) (*sobek.Promise, error) {
+	return func(path sobek.Value, handler sobek.Callable) (*sobek.Promise, error) {
+		ctx := vu.Context()
+
+		tq := vu.get(ctx, p.TargetID())
+
+		// Inject JS regex checker for URL regex pattern matching
+		jsRegexChecker, err := injectRegexMatcherScript(ctx, vu, tq)
+		if err != nil {
+			return nil, err
+		}
+		pathStr := parseStringOrRegex(path, false)
+
+		// Run the event handler in the task queue to
+		// ensure that the handler is executed on the event loop.
+		routeHandler := func(route *common.Route) error {
+			done := make(chan error, 1)
+			tq.Queue(func() error {
+				defer close(done)
+
+				mr := mapRoute(vu, route)
+				_, err = handler(
+					sobek.Undefined(),
+					vu.Runtime().ToValue(mr),
+				)
+				if err != nil {
+					done <- fmt.Errorf("executing page.route('%s') handler: %w", path, err)
+					return nil
+				}
+
+				return nil
+			})
+
+			select {
+			case err := <-done:
+				return err
+			case <-ctx.Done():
+				return errors.New("iteration ended before route completed")
+			}
+		}
+
+		return k6ext.Promise(vu.Context(), func() (any, error) {
+			return nil, p.Route(pathStr, routeHandler, jsRegexChecker)
+		}), nil
+	}
+}
+
+func waitForURLBodyImpl(vu moduleVU, target interface {
+	Timeout() time.Duration
+	WaitForURL(urlPattern string, opts *common.FrameWaitForURLOptions, jsRegexChecker common.JSRegexChecker) error
+}, url sobek.Value, opts sobek.Value,
+) (*sobek.Promise, error) {
+	if k6common.IsNullish(url) {
+		return nil, errors.New("missing required argument 'url'")
+	}
+	popts := common.NewFrameWaitForURLOptions(target.Timeout())
+	if err := popts.Parse(vu.Context(), opts); err != nil {
+		return nil, fmt.Errorf("parsing waitForURL options: %w", err)
+	}
+
+	var val string
+	switch url.ExportType() {
+	case reflect.TypeOf(string("")):
+		val = fmt.Sprintf("'%s'", url.String()) // Strings require quotes
+	default: // JS Regex, CSS, numbers or booleans
+		val = url.String() // No quotes
+	}
+
+	// Inject JS regex checker for URL pattern matching
+	ctx, stopTaskqueue := context.WithCancel(vu.Context())
+	tq := cancelableTaskQueue(ctx, vu.RegisterCallback)
+
+	jsRegexChecker, err := injectRegexMatcherScript(ctx, vu, tq)
+	if err != nil {
+		stopTaskqueue()
+		return nil, err
+	}
+
+	return k6ext.Promise(ctx, func() (result any, reason error) {
+		defer stopTaskqueue()
+		return nil, target.WaitForURL(val, popts, jsRegexChecker)
+	}), nil
+}
+
+func waitForNavigationBodyImpl(vu moduleVU, target interface {
+	Timeout() time.Duration
+	WaitForNavigation(*common.FrameWaitForNavigationOptions, common.JSRegexChecker) (*common.Response, error)
+}, opts sobek.Value,
+) (*sobek.Promise, error) {
+	popts := common.NewFrameWaitForNavigationOptions(target.Timeout())
+	if err := popts.Parse(vu.Context(), opts); err != nil {
+		return nil, fmt.Errorf("parsing frame wait for navigation options: %w", err)
+	}
+
+	ctx := vu.Context()
+
+	// Avoid working with the taskqueue unless the URL option is used.
+	// At the moment the taskqueue needs to be cleaned up manually with
+	// page.close.
+	var jsRegexChecker common.JSRegexChecker
+	stopTaskqueue := func() {}
+	if popts.URL != "" {
+		ctx, stopTaskqueue = context.WithCancel(ctx)
+		tq := cancelableTaskQueue(ctx, vu.RegisterCallback)
+
+		// Inject JS regex checker for URL regex pattern matching
+		var err error
+		jsRegexChecker, err = injectRegexMatcherScript(ctx, vu, tq)
+		if err != nil {
+			stopTaskqueue()
+			return nil, err
+		}
+	}
+
+	return k6ext.Promise(ctx, func() (result any, reason error) {
+		defer stopTaskqueue()
+		resp, err := target.WaitForNavigation(popts, jsRegexChecker)
+		if err != nil {
+			return nil, err //nolint:wrapcheck
+		}
+		return mapResponse(vu, resp), nil
+	}), nil
+}
