@@ -6,6 +6,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"strconv"
 	"strings"
 	"sync"
 	"time"
@@ -78,6 +79,34 @@ func (s *DOMElementState) UnmarshalJSON(b []byte) error {
 	return nil
 }
 
+// URLMatcher is a function that matches a URL against a pattern.
+// It relies on JavaScript's regex engine for regex matching.
+type URLMatcher func(string) (bool, error)
+
+// urlMatcher matches URLs based on pattern type. It can match on exact and regex
+// patterns. If the pattern is empty or a single quote, it matches any URL.
+func urlMatcher(pattern string, jsRegexChecker JSRegexChecker) (URLMatcher, error) {
+	if pattern == "" || pattern == "''" {
+		return func(url string) (bool, error) { return true, nil }, nil
+	}
+
+	if isQuotedText(pattern) {
+		return func(url string) (bool, error) { return "'"+url+"'" == pattern, nil }, nil
+	}
+
+	if jsRegexChecker == nil {
+		return nil, fmt.Errorf("JavaScript pattern matcher is required for URL matching")
+	}
+
+	return func(url string) (bool, error) {
+		matched, err := jsRegexChecker(pattern, url)
+		if err != nil {
+			return false, fmt.Errorf("URL pattern matching error for pattern %q and URL %q: %w", pattern, url, err)
+		}
+		return matched, nil
+	}, nil
+}
+
 // Frame represents a frame in an HTML document.
 type Frame struct {
 	BaseEventEmitter
@@ -1002,6 +1031,148 @@ func (f *Frame) getAttribute(selector, name string, opts *FrameBaseOptions) (str
 	return s, true, nil
 }
 
+// GetByRole creates and returns a new locator for this frame using the ARIA role
+// and any additional options.
+func (f *Frame) GetByRole(role string, opts *GetByRoleOptions) *Locator {
+	f.log.Debugf("Frame:GetByRole", "fid:%s furl:%q role:%q opts:%+v", f.ID(), f.URL(), role, opts)
+
+	properties := make(map[string]string)
+
+	if opts == nil {
+		return f.Locator("internal:role="+role, nil)
+	}
+
+	if opts.Checked != nil {
+		properties["checked"] = strconv.FormatBool(*opts.Checked)
+	}
+	if opts.Disabled != nil {
+		properties["disabled"] = strconv.FormatBool(*opts.Disabled)
+	}
+	if opts.Selected != nil {
+		properties["selected"] = strconv.FormatBool(*opts.Selected)
+	}
+	if opts.Expanded != nil {
+		properties["expanded"] = strconv.FormatBool(*opts.Expanded)
+	}
+	if opts.IncludeHidden != nil {
+		properties["include-hidden"] = strconv.FormatBool(*opts.IncludeHidden)
+	}
+	if opts.Level != nil {
+		properties["level"] = strconv.FormatInt(*opts.Level, 10)
+	}
+	if opts.Name != nil && *opts.Name != "" {
+		// Exact option can only be applied to quoted strings.
+		if isQuotedText(*opts.Name) {
+			if opts.Exact != nil && *opts.Exact {
+				*opts.Name = (*opts.Name) + "s"
+			} else {
+				*opts.Name = (*opts.Name) + "i"
+			}
+		}
+		properties["name"] = *opts.Name
+	}
+	if opts.Pressed != nil {
+		properties["pressed"] = strconv.FormatBool(*opts.Pressed)
+	}
+
+	var builder strings.Builder
+	builder.WriteString("internal:role=" + role)
+	for key, value := range properties {
+		builder.WriteString("[" + key + "=" + value + "]")
+	}
+
+	return f.Locator(builder.String(), nil)
+}
+
+// isQuotedText returns true if the string is a quoted string.
+// This is used to determine if the string will be used to match
+// a string instead of as a regex in the getBy* APIs. It handles
+// both single and double quotes.
+func isQuotedText(s string) bool {
+	switch {
+	case len(s) > 0 && s[0] == '\'' && s[len(s)-1] == '\'':
+		return true
+	case len(s) > 0 && s[0] == '"' && s[len(s)-1] == '"':
+		return true
+	}
+	return false
+}
+
+// buildAttributeSelector is a helper method that builds an attribute selector
+// for use with the internal:attr engine. It handles quoted strings and
+// applies the appropriate suffix for exact or case-insensitive matching.
+func (f *Frame) buildAttributeSelector(attrName, attrValue string, opts *GetByBaseOptions) string {
+	selector := "[" + attrName + "=" + attrValue + "]"
+	if isQuotedText(attrValue) {
+		if opts != nil && opts.Exact != nil && *opts.Exact {
+			selector = "[" + attrName + "=" + attrValue + "s]"
+		} else {
+			selector = "[" + attrName + "=" + attrValue + "i]"
+		}
+	}
+	return selector
+}
+
+// Locator creates and returns a new locator for this frame.
+func (f *Frame) GetByAltText(alt string, opts *GetByBaseOptions) *Locator {
+	f.log.Debugf("Frame:GetByAltText", "fid:%s furl:%q alt:%q opts:%+v", f.ID(), f.URL(), alt, opts)
+
+	return f.Locator("internal:attr="+f.buildAttributeSelector("alt", alt, opts), nil)
+}
+
+// Locator creates and returns a new locator for this frame.
+func (f *Frame) GetByLabel(label string, opts *GetByBaseOptions) *Locator {
+	f.log.Debugf("Frame:GetByLabel", "fid:%s furl:%q label:%q opts:%+v", f.ID(), f.URL(), label, opts)
+
+	l := "internal:label=" + label
+	if isQuotedText(label) {
+		if opts != nil && opts.Exact != nil && *opts.Exact {
+			l = "internal:label=" + label + "s"
+		} else {
+			l = "internal:label=" + label + "i"
+		}
+	}
+
+	return f.Locator(l, nil)
+}
+
+// GetByPlaceholder creates and returns a new locator for this frame based on the placeholder attribute.
+func (f *Frame) GetByPlaceholder(placeholder string, opts *GetByBaseOptions) *Locator {
+	f.log.Debugf("Frame:GetByPlaceholder", "fid:%s furl:%q placeholder:%q opts:%+v", f.ID(), f.URL(), placeholder, opts)
+
+	return f.Locator("internal:attr="+f.buildAttributeSelector("placeholder", placeholder, opts), nil)
+}
+
+// GetByTitle creates and returns a new locator for this frame based on the title attribute.
+func (f *Frame) GetByTitle(title string, opts *GetByBaseOptions) *Locator {
+	f.log.Debugf("Frame:GetByTitle", "fid:%s furl:%q title:%q opts:%+v", f.ID(), f.URL(), title, opts)
+
+	return f.Locator("internal:attr="+f.buildAttributeSelector("title", title, opts), nil)
+}
+
+// GetByTestID creates and returns a new locator for this frame based on the data-testid attribute.
+func (f *Frame) GetByTestID(testID string) *Locator {
+	f.log.Debugf("Frame:GetByTestID", "fid:%s furl:%q testID:%q", f.ID(), f.URL(), testID)
+
+	return f.Locator("internal:attr=[data-testid="+testID+"]", nil)
+}
+
+// GetByText creates and returns a new locator for this frame based on text content.
+func (f *Frame) GetByText(text string, opts *GetByBaseOptions) *Locator {
+	f.log.Debugf("Frame:GetByText", "fid:%s furl:%q text:%q opts:%+v", f.ID(), f.URL(), text, opts)
+
+	l := "internal:text=" + text
+	if isQuotedText(text) {
+		if opts != nil && opts.Exact != nil && *opts.Exact {
+			l = "internal:text=" + text + "s"
+		} else {
+			l = "internal:text=" + text + "i"
+		}
+	}
+
+	return f.Locator(l, nil)
+}
+
 // Referrer returns the referrer of the frame from the network manager
 // of the frame's session.
 // It's an internal method not to be exposed as a JS API.
@@ -1024,7 +1195,7 @@ func (f *Frame) Goto(url string, opts *FrameGotoOptions) (*Response, error) {
 	}
 	applySlowMo(f.ctx)
 
-	// Since response will be in an interface, it will never be nil,
+	// Since the response will be in an interface, it will never be nil,
 	// so we need to return nil explicitly.
 	if resp == nil {
 		return nil, nil //nolint:nilnil
@@ -1812,41 +1983,56 @@ func (f *Frame) WaitForLoadState(state string, popts *FrameWaitForLoadStateOptio
 }
 
 // WaitForNavigation waits for the given navigation lifecycle event to happen.
-func (f *Frame) WaitForNavigation(opts *FrameWaitForNavigationOptions) (*Response, error) {
+// jsRegexChecker should be non-nil to be able to test against a URL pattern in the options.
+//
+//nolint:funlen
+func (f *Frame) WaitForNavigation(
+	opts *FrameWaitForNavigationOptions,
+	jsRegexChecker JSRegexChecker,
+) (*Response, error) {
 	f.log.Debugf("Frame:WaitForNavigation",
-		"fid:%s furl:%s", f.ID(), f.URL())
+		"fid:%s furl:%s url:%s", f.ID(), f.URL(), opts.URL)
 	defer f.log.Debugf("Frame:WaitForNavigation:return",
 		"fid:%s furl:%s", f.ID(), f.URL())
 
 	timeoutCtx, timeoutCancel := context.WithTimeout(f.ctx, opts.Timeout)
 
-	navEvtCh, navEvtCancel := createWaitForEventHandler(timeoutCtx, f, []string{EventFrameNavigation},
+	// Create URL matcher based on the pattern
+	matcher, err := urlMatcher(opts.URL, jsRegexChecker)
+	if err != nil {
+		timeoutCancel()
+		return nil, fmt.Errorf("parsing URL pattern: %w", err)
+	}
+
+	var matcherErr error
+	navEvtCh, navEvtCancel := createWaitForEventPredicateHandler(timeoutCtx, f, []string{EventFrameNavigation},
 		func(data any) bool {
-			return true // Both successful and failed navigations are considered
+			if navEvt, ok := data.(*NavigationEvent); ok {
+				// Check if the navigation URL matches the pattern
+				matched, err := matcher(navEvt.url)
+				if err != nil {
+					matcherErr = err
+					// Return true here even though it's not correct and no match
+					// was found. We need this to exit asap so that the error can be
+					// propagated to the caller.
+					return true
+				}
+				return matched
+			}
+			return false
 		})
 
 	lifecycleEvtCh, lifecycleEvtCancel := createWaitForEventPredicateHandler(
 		timeoutCtx, f, []string{EventFrameAddLifecycle},
 		func(data any) bool {
+			// Wait for the lifecycle event to happen.
 			if le, ok := data.(FrameLifecycleEvent); ok {
 				return le.Event == opts.WaitUntil
 			}
 			return false
 		})
 
-	handleTimeoutError := func(err error) error {
-		f.log.Debugf("Frame:WaitForNavigation",
-			"fid:%v furl:%s timeoutCtx done: %v", f.ID(), f.URL(), err)
-		if err != nil {
-			e := &k6ext.UserFriendlyError{
-				Err:     err,
-				Timeout: opts.Timeout,
-			}
-			return fmt.Errorf("waiting for navigation: %w", e)
-		}
-
-		return nil
-	}
+	handleTimeoutError := f.handleWaitForNavigationTimeoutErrorFn(opts)
 
 	defer func() {
 		timeoutCancel()
@@ -1860,7 +2046,14 @@ func (f *Frame) WaitForNavigation(opts *FrameWaitForNavigationOptions) (*Respons
 	)
 	select {
 	case evt := <-navEvtCh:
+		if matcherErr != nil {
+			return nil, matcherErr
+		}
 		if e, ok := evt.(*NavigationEvent); ok {
+			if e.err != nil {
+				return nil, e.err
+			}
+
 			if e.newDocument == nil {
 				sameDocNav = true
 				break
@@ -1888,7 +2081,7 @@ func (f *Frame) WaitForNavigation(opts *FrameWaitForNavigationOptions) (*Respons
 		}
 	}
 
-	// Since response will be in an interface, it will never be nil,
+	// Since the response will be in an interface, it will never be nil,
 	// so we need to return nil explicitly.
 	if resp == nil {
 		return nil, nil //nolint:nilnil
@@ -1897,6 +2090,25 @@ func (f *Frame) WaitForNavigation(opts *FrameWaitForNavigationOptions) (*Respons
 	return resp, nil
 }
 
+func (f *Frame) handleWaitForNavigationTimeoutErrorFn(opts *FrameWaitForNavigationOptions) func(err error) error {
+	return func(err error) error {
+		f.log.Debugf("Frame:WaitForNavigation",
+			"fid:%v furl:%s timeoutCtx done: %v", f.ID(), f.URL(), err)
+		if err != nil {
+			e := &k6ext.UserFriendlyError{
+				Err:     err,
+				Timeout: opts.Timeout,
+			}
+			if opts.URL != "" {
+				return fmt.Errorf("waiting for navigation to URL matching %q: %w", opts.URL, e)
+			}
+			return fmt.Errorf("waiting for navigation: %w", e)
+		}
+
+		return nil
+	}
+}
+
 // WaitForSelector waits for the given selector to match the waiting criteria.
 func (f *Frame) WaitForSelector(selector string, popts *FrameWaitForSelectorOptions) (*ElementHandle, error) {
 	handle, err := f.waitForSelectorRetry(selector, popts, maxRetry)
@@ -1920,6 +2132,38 @@ func (f *Frame) WaitForTimeout(timeout int64) {
 	}
 }
 
+// WaitForURL waits for the frame to navigate to a URL matching the given pattern.
+// jsRegexChecker should be non-nil to be able to test against a URL pattern.
+func (f *Frame) WaitForURL(urlPattern string, opts *FrameWaitForURLOptions, jsRegexChecker JSRegexChecker) error {
+	f.log.Debugf("Frame:WaitForURL", "fid:%s furl:%q pattern:%s", f.ID(), f.URL(), urlPattern)
+	defer f.log.Debugf("Frame:WaitForURL:return", "fid:%s furl:%q pattern:%s", f.ID(), f.URL(), urlPattern)
+
+	matcher, err := urlMatcher(urlPattern, jsRegexChecker)
+	if err != nil {
+		return fmt.Errorf("parsing URL pattern: %w", err)
+	}
+
+	matched, err := matcher(f.URL())
+	if err != nil {
+		return fmt.Errorf("checking current URL: %w", err)
+	}
+	if matched {
+		// Already at target URL, just wait for load state
+		return f.WaitForLoadState(opts.WaitUntil.String(), &FrameWaitForLoadStateOptions{
+			Timeout: opts.Timeout,
+		})
+	}
+
+	// Wait for navigation to matching URL
+	navOpts := &FrameWaitForNavigationOptions{
+		URL:       urlPattern,
+		Timeout:   opts.Timeout,
+		WaitUntil: opts.WaitUntil,
+	}
+	_, err = f.WaitForNavigation(navOpts, jsRegexChecker)
+	return err
+}
+
 func (f *Frame) adoptBackendNodeID(world executionWorld, id cdp.BackendNodeID) (*ElementHandle, error) {
 	f.log.Debugf("Frame:adoptBackendNodeID", "fid:%s furl:%q world:%s id:%d", f.ID(), f.URL(), world, id)
 
