@@ -540,7 +540,45 @@ func (m *FrameManager) requestStarted(req *Request) {
 		frame.pendingDocument = &DocumentInfo{documentID: req.documentID, request: req}
 		frame.pendingDocumentMu.Unlock()
 	}
-	m.logger.Debugf("FrameManager:requestStarted", "fmid:%d rurl:%s pdoc:nil", m.ID(), req.URL())
+
+	if !m.page.hasRoutes() {
+		return
+	}
+
+	route := NewRoute(m.logger, m.page.mainFrameSession.networkManager, req)
+	m.page.routesMu.RLock()
+	defer m.page.routesMu.RUnlock()
+	for _, r := range m.page.routes {
+		matched, err := r.urlMatcher(req.URL())
+		if err != nil {
+			m.logger.Errorf("FrameManager:requestStarted",
+				"fmid:%d rurl:%s error matching url: %v", m.ID(), req.URL(), err)
+			continue
+		}
+
+		if !matched {
+			continue
+		}
+
+		func() {
+			// In case routes are updated in the handler
+			m.page.routesMu.RUnlock()
+			defer m.page.routesMu.RLock()
+
+			err := r.handler(route)
+			if err != nil {
+				m.logger.Errorf("FrameManager:requestStarted",
+					"fmid:%d rurl:%s error handling request with route: %v", m.ID(), req.URL(), err)
+			}
+		}()
+
+		return
+	}
+
+	if err := route.Continue(ContinueOptions{}); err != nil {
+		m.logger.Errorf("FrameManager:requestStarted",
+			"fmid:%d rurl:%s error continuing request: %v", m.ID(), req.URL(), err)
+	}
 }
 
 // Frames returns a list of frames on the page.
@@ -582,7 +620,7 @@ func (m *FrameManager) MainFrameURL() string {
 	return m.mainFrame.URL()
 }
 
-// NavigateFrame will navigate specified frame to specified URL.
+// NavigateFrame will navigate a specified frame to specified URL.
 //
 //nolint:funlen
 func (m *FrameManager) NavigateFrame(frame *Frame, url string, parsedOpts *FrameGotoOptions) (*Response, error) {
@@ -599,14 +637,21 @@ func (m *FrameManager) NavigateFrame(frame *Frame, url string, parsedOpts *Frame
 	timeoutCtx, timeoutCancelFn := context.WithTimeout(m.ctx, parsedOpts.Timeout)
 	defer timeoutCancelFn()
 
-	newDocIDCh := make(chan string, 1)
-	navEvtCh, navEvtCancel := createWaitForEventHandler(
+	var newDocumentID string
+	newDocIDIsReadyCh := make(chan struct{})
+
+	navEvtCh, navEvtCancel := createWaitForEventPredicateHandler(
 		timeoutCtx, frame, []string{EventFrameNavigation},
 		func(data any) bool {
-			newDocID := <-newDocIDCh
+			select {
+			case <-newDocIDIsReadyCh:
+			case <-timeoutCtx.Done():
+				return false
+			}
+
 			if evt, ok := data.(*NavigationEvent); ok {
 				if evt.newDocument != nil {
-					return evt.newDocument.documentID == newDocID
+					return evt.newDocument.documentID == newDocumentID
 				}
 			}
 			return false
@@ -648,20 +693,22 @@ func (m *FrameManager) NavigateFrame(frame *Frame, url string, parsedOpts *Frame
 		// main frame's session.
 		fs = frame.page.mainFrameSession
 	}
-	newDocumentID, err := fs.navigateFrame(frame, url, parsedOpts.Referer)
+
+	var err error
+	newDocumentID, err = fs.navigateFrame(frame, url, parsedOpts.Referer)
 	if err != nil {
 		return nil, fmt.Errorf("navigating to %q: %w", url, err)
 	}
 
 	if newDocumentID == "" {
-		// It's a navigation within the same document (e.g. via anchor links or
+		// It's a navigation within the same document (e.g., via anchor links or
 		// the History API), so don't wait for a response nor any lifecycle
 		// events.
 		return nil, nil //nolint:nilnil
 	}
 
 	// unblock the waiter goroutine
-	newDocIDCh <- newDocumentID
+	close(newDocIDIsReadyCh)
 
 	wrapTimeoutError := func(err error) error {
 		if errors.Is(err, context.DeadlineExceeded) {
@@ -682,6 +729,10 @@ func (m *FrameManager) NavigateFrame(frame *Frame, url string, parsedOpts *Frame
 	select {
 	case evt := <-navEvtCh:
 		if e, ok := evt.(*NavigationEvent); ok {
+			if e.err != nil {
+				return nil, e.err
+			}
+
 			req := e.newDocument.request
 			// Request could be nil in case of navigation to e.g. BlankPage.
 			if req != nil {
