@@ -186,6 +186,9 @@ type FrameWaitForLoadStateOptions struct {
 	Timeout time.Duration `json:"timeout"`
 }
 
+// JSRegexChecker is a function that performs regex matching using JavaScript's regex engine
+type JSRegexChecker func(pattern, url string) (bool, error)
+
 type FrameWaitForNavigationOptions struct {
 	URL       string         `json:"url"`
 	WaitUntil LifecycleEvent `json:"waitUntil" js:"waitUntil"`
@@ -682,7 +685,15 @@ func (o *FrameWaitForNavigationOptions) Parse(ctx context.Context, opts sobek.Va
 		for _, k := range opts.Keys() {
 			switch k {
 			case "url":
-				o.URL = opts.Get(k).String()
+				var val string
+				switch opts.Get(k).ExportType() {
+				case reflect.TypeOf(string("")):
+					val = fmt.Sprintf("'%s'", opts.Get(k).String()) // Strings require quotes
+				default: // JS Regex, CSS, numbers or booleans
+					val = opts.Get(k).String() // No quotes
+				}
+
+				o.URL = val
 			case "timeout":
 				o.Timeout = time.Duration(opts.Get(k).ToInteger()) * time.Millisecond
 			case "waitUntil":
@@ -757,3 +768,37 @@ func parseStrict(ctx context.Context, opts sobek.Value) bool {
 
 	return strict
 }
+
+// FrameWaitForURLOptions are options for Frame.waitForURL and Page.waitForURL.
+type FrameWaitForURLOptions struct {
+	Timeout   time.Duration
+	WaitUntil LifecycleEvent
+}
+
+// NewFrameWaitForURLOptions returns a new FrameWaitForURLOptions.
+func NewFrameWaitForURLOptions(defaultTimeout time.Duration) *FrameWaitForURLOptions {
+	return &FrameWaitForURLOptions{
+		Timeout:   defaultTimeout,
+		WaitUntil: LifecycleEventLoad,
+	}
+}
+
+// Parse parses the frame waitForURL options.
+func (o *FrameWaitForURLOptions) Parse(ctx context.Context, opts sobek.Value) error {
+	rt := k6ext.Runtime(ctx)
+	if opts != nil && !sobek.IsUndefined(opts) && !sobek.IsNull(opts) {
+		opts := opts.ToObject(rt)
+		for _, k := range opts.Keys() {
+			switch k {
+			case "timeout":
+				o.Timeout = time.Duration(opts.Get(k).ToInteger()) * time.Millisecond
+			case "waitUntil":
+				lifeCycle := opts.Get(k).String()
+				if err := o.WaitUntil.UnmarshalText([]byte(lifeCycle)); err != nil {
+					return fmt.Errorf("parsing waitForURL options: %w", err)
+				}
+			}
+		}
+	}
+	return nil
+}
