@@ -190,6 +190,26 @@ type ConsoleMessage struct {
 
 type PageOnHandler func(PageOnEvent) error
 
+type RouteHandler struct {
+	path       string
+	handler    RouteHandlerCallback
+	urlMatcher URLMatcher
+}
+
+func NewRouteHandler(
+	path string,
+	handler RouteHandlerCallback,
+	urlMatcher URLMatcher,
+) *RouteHandler {
+	return &RouteHandler{
+		path:       path,
+		handler:    handler,
+		urlMatcher: urlMatcher,
+	}
+}
+
+type RouteHandlerCallback func(*Route) error
+
 // Page stores Page/tab related context.
 type Page struct {
 	Keyboard    *Keyboard
@@ -234,7 +254,8 @@ type Page struct {
 	frameSessionsMu  sync.RWMutex
 	workers          map[target.SessionID]*Worker
 	workersMu        sync.Mutex
-	routes           []any // TODO: Implement
+	routes           []*RouteHandler
+	routesMu         sync.RWMutex
 	vu               k6modules.VU
 
 	logger *log.Logger
@@ -765,6 +786,9 @@ func (p *Page) getFrameSession(frameID cdp.FrameID) (*FrameSession, bool) {
 }
 
 func (p *Page) hasRoutes() bool {
+	p.routesMu.RLock()
+	defer p.routesMu.RUnlock()
+
 	return len(p.routes) > 0
 }
 
@@ -1087,6 +1111,56 @@ func (p *Page) GetAttribute(selector string, name string, popts *FrameBaseOption
 	return p.MainFrame().GetAttribute(selector, name, popts)
 }
 
+// GetByRole creates and returns a new locator for this page (main frame) based on their ARIA role.
+func (p *Page) GetByRole(role string, opts *GetByRoleOptions) *Locator {
+	p.logger.Debugf("Page:GetByRole", "sid:%s role: %q opts:%+v", p.sessionID(), role, opts)
+
+	return p.MainFrame().GetByRole(role, opts)
+}
+
+// GetByAltText creates and returns a new locator for this page (main frame)
+// based on the alt attribute text.
+func (p *Page) GetByAltText(alt string, opts *GetByBaseOptions) *Locator {
+	p.logger.Debugf("Page:GetByAltText", "sid:%s alt: %q opts:%+v", p.sessionID(), alt, opts)
+
+	return p.MainFrame().GetByAltText(alt, opts)
+}
+
+// GetByLabel creates and returns a new locator for this page (main frame) based on the label text.
+func (p *Page) GetByLabel(label string, opts *GetByBaseOptions) *Locator {
+	p.logger.Debugf("Page:GetByLabel", "sid:%s label: %q opts:%+v", p.sessionID(), label, opts)
+
+	return p.MainFrame().GetByLabel(label, opts)
+}
+
+// GetByPlaceholder creates and returns a new locator for this page (main frame) based on the placeholder attribute.
+func (p *Page) GetByPlaceholder(placeholder string, opts *GetByBaseOptions) *Locator {
+	p.logger.Debugf("Page:GetByPlaceholder", "sid:%s placeholder: %q opts:%+v", p.sessionID(), placeholder, opts)
+
+	return p.MainFrame().GetByPlaceholder(placeholder, opts)
+}
+
+// GetByTitle creates and returns a new locator for this page (main frame) based on the title attribute.
+func (p *Page) GetByTitle(title string, opts *GetByBaseOptions) *Locator {
+	p.logger.Debugf("Page:GetByTitle", "sid:%s title: %q opts:%+v", p.sessionID(), title, opts)
+
+	return p.MainFrame().GetByTitle(title, opts)
+}
+
+// GetByTestID creates and returns a new locator for this page (main frame) based on the data-testid attribute.
+func (p *Page) GetByTestID(testID string) *Locator {
+	p.logger.Debugf("Page:GetByTestID", "sid:%s testID: %q", p.sessionID(), testID)
+
+	return p.MainFrame().GetByTestID(testID)
+}
+
+// GetByText creates and returns a new locator for this page (main frame) based on text content.
+func (p *Page) GetByText(text string, opts *GetByBaseOptions) *Locator {
+	p.logger.Debugf("Page:GetByText", "sid:%s text: %q opts:%+v", p.sessionID(), text, opts)
+
+	return p.MainFrame().GetByText(text, opts)
+}
+
 // GetKeyboard returns the keyboard for the page.
 func (p *Page) GetKeyboard() *Keyboard {
 	return p.Keyboard
@@ -1227,6 +1301,36 @@ func (p *Page) Referrer() string {
 	return nm.extraHTTPHeaders["referer"]
 }
 
+// Route register a handler to be executed for a given request path
+func (p *Page) Route(
+	path string,
+	handlerCallback RouteHandlerCallback,
+	jsRegexChecker JSRegexChecker,
+) error {
+	p.logger.Debugf("Page:Route", "sid:%v path:%s", p.sessionID(), path)
+
+	if !p.hasRoutes() {
+		err := p.mainFrameSession.updateRequestInterception(true)
+		if err != nil {
+			return err
+		}
+	}
+
+	matcher, err := urlMatcher(path, jsRegexChecker)
+	if err != nil {
+		return fmt.Errorf("creating url matcher for path %s: %w", path, err)
+	}
+
+	routeHandler := NewRouteHandler(path, handlerCallback, matcher)
+	p.routesMu.Lock()
+	defer p.routesMu.Unlock()
+	// Append new route at the beginning of the slice as, when several routes match the given pattern,
+	// they will run in the opposite order to their registration.
+	p.routes = append([]*RouteHandler{routeHandler}, p.routes...)
+
+	return nil
+}
+
 // NavigationTimeout returns the page's navigation timeout.
 // It's an internal method not to be exposed as a JS API.
 func (p *Page) NavigationTimeout() time.Duration {
@@ -1353,6 +1457,8 @@ func (p *Page) Reload(opts *PageReloadOptions) (*Response, error) { //nolint:fun
 		var ok bool
 		if navigationEvent, ok = event.(*NavigationEvent); !ok {
 			err = fmt.Errorf("unexpected event data type: %T, expected *NavigationEvent", event)
+		} else if navigationEvent != nil && navigationEvent.err != nil {
+			err = navigationEvent.err
 		}
 	}
 	if err != nil {
@@ -1541,17 +1647,7 @@ func (p *Page) Type(selector string, text string, popts *FrameTypeOptions) error
 func (p *Page) URL() (string, error) {
 	p.logger.Debugf("Page:URL", "sid:%v", p.sessionID())
 
-	js := `() => document.location.toString()`
-	v, err := p.Evaluate(js)
-	if err != nil {
-		return "", fmt.Errorf("getting page URL: %w", err)
-	}
-	s, ok := v.(string)
-	if !ok {
-		return "", fmt.Errorf("getting page URL: expected string, got %T", v)
-	}
-
-	return s, nil
+	return p.MainFrame().url, nil
 }
 
 // ViewportSize will return information on the viewport width and height.
@@ -1579,12 +1675,16 @@ func (p *Page) WaitForLoadState(state string, popts *FrameWaitForLoadStateOption
 }
 
 // WaitForNavigation waits for the given navigation lifecycle event to happen.
-func (p *Page) WaitForNavigation(opts *FrameWaitForNavigationOptions) (*Response, error) {
+// jsRegexChecker should be non-nil to be able to test against a URL pattern in the options.
+func (p *Page) WaitForNavigation(
+	opts *FrameWaitForNavigationOptions,
+	jsRegexChecker JSRegexChecker,
+) (*Response, error) {
 	p.logger.Debugf("Page:WaitForNavigation", "sid:%v", p.sessionID())
 	_, span := TraceAPICall(p.ctx, p.targetID.String(), "page.waitForNavigation")
 	defer span.End()
 
-	resp, err := p.frameManager.MainFrame().WaitForNavigation(opts)
+	resp, err := p.frameManager.MainFrame().WaitForNavigation(opts, jsRegexChecker)
 	if err != nil {
 		spanRecordError(span, err)
 		return nil, err
@@ -1612,6 +1712,22 @@ func (p *Page) WaitForTimeout(timeout int64) {
 	p.frameManager.MainFrame().WaitForTimeout(timeout)
 }
 
+// WaitForURL waits for the page to navigate to a URL matching the given pattern.
+// jsRegexChecker should be non-nil to be able to test against a URL pattern.
+func (p *Page) WaitForURL(urlPattern string, opts *FrameWaitForURLOptions, jsRegexChecker JSRegexChecker) error {
+	p.logger.Debugf("Page:WaitForURL", "sid:%v pattern:%s", p.sessionID(), urlPattern)
+	_, span := TraceAPICall(p.ctx, p.targetID.String(), "page.waitForURL")
+	defer span.End()
+
+	err := p.frameManager.MainFrame().WaitForURL(urlPattern, opts, jsRegexChecker)
+	if err != nil {
+		spanRecordError(span, err)
+		return err
+	}
+
+	return nil
+}
+
 // Workers returns all WebWorkers of page.
 func (p *Page) Workers() []*Worker {
 	p.workersMu.Lock()
