@@ -20,10 +20,10 @@ import (
 	"github.com/grafana/sobek"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	k6metrics "go.k6.io/k6/metrics"
 
 	"go.k6.io/k6/internal/js/modules/k6/browser/common"
 	"go.k6.io/k6/internal/js/modules/k6/browser/k6ext/k6test"
+	"go.k6.io/k6/metrics"
 )
 
 type emulateMediaOpts struct {
@@ -248,6 +248,8 @@ func TestPageEvaluateMapping(t *testing.T) {
 				tt.script,
 			)
 			assert.Equal(t, tb.vu.ToSobekValue(tt.want), got.Result())
+			// Test script as string input
+			_ = tb.vu.RunPromise(t, `await p.close()`)
 		})
 	}
 }
@@ -950,8 +952,7 @@ func TestPageWaitForNavigationErrOnCtxDone(t *testing.T) {
 	go b.cancelContext()
 	<-b.context().Done()
 	_, err := p.WaitForNavigation(
-		common.NewFrameWaitForNavigationOptions(p.Timeout()),
-	)
+		common.NewFrameWaitForNavigationOptions(p.Timeout()), nil)
 	require.ErrorContains(t, err, "canceled")
 }
 
@@ -1762,14 +1763,11 @@ func TestPageIsHidden(t *testing.T) {
 	}
 }
 
-func TestShadowDOMAndDocumentFragment(t *testing.T) { //nolint:tparallel
+func TestShadowDOMAndDocumentFragment(t *testing.T) {
 	t.Parallel()
 	if runtime.GOOS == "windows" {
-		t.Skip() // timeouts
+		t.Skip("windows timeouts on these tests")
 	}
-
-	tb := newTestBrowser(t, withFileServer())
-
 	tests := []struct {
 		name     string
 		selector string
@@ -1796,8 +1794,10 @@ func TestShadowDOMAndDocumentFragment(t *testing.T) { //nolint:tparallel
 		},
 	}
 
-	for _, tt := range tests { //nolint:paralleltest
+	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
+			t.Parallel()
+			tb := newTestBrowser(t, withFileServer())
 			tb.vu.ActivateVU()
 			tb.vu.StartIteration(t)
 			defer tb.vu.EndIteration(t)
@@ -1813,6 +1813,7 @@ func TestShadowDOMAndDocumentFragment(t *testing.T) { //nolint:tparallel
 				});
 
 				const text = await s.innerText();
+				await p.close()
 				return text;
  			`, tb.staticURL("shadow_and_doc_frag.html"), tt.selector)
 			assert.Equal(t, tt.want, got.Result().String())
@@ -2085,7 +2086,7 @@ func TestPageOnMetric(t *testing.T) {
 
 			done := make(chan bool)
 
-			samples := make(chan k6metrics.SampleContainer)
+			samples := make(chan metrics.SampleContainer)
 			// This page will perform many pings with a changing h query parameter.
 			// This URL should be grouped according to how page.on('metric') is used.
 			tb := newTestBrowser(t, withHTTPServer(), withSamples(samples))
@@ -2787,3 +2788,212 @@ func TestPageMustUseNativeJavaScriptObjects(t *testing.T) {
 	_, err = page.QueryAll("#textField")
 	require.NoErrorf(t, err, "page should not override the native objects, but it did")
 }
+
+func TestWaitForNavigationWithURL(t *testing.T) {
+	if runtime.GOOS == "windows" {
+		t.Skip("Skipped due to https://github.com/grafana/k6/issues/4937")
+	}
+
+	t.Parallel()
+
+	tb := newTestBrowser(t, withFileServer())
+	tb.vu.ActivateVU()
+	tb.vu.StartIteration(t)
+
+	got := tb.vu.RunPromise(t, `
+		const page = await browser.newPage();
+		const testURL = '%s';
+
+		try {
+			await page.goto(testURL);
+
+			// Test exact URL match
+			await Promise.all([
+				page.waitForNavigation({ url: '%s' }),
+				page.locator('#page1').click()
+			]);
+			let currentURL = page.url();
+			if (!currentURL.endsWith('page1.html')) {
+				throw new Error('Expected to navigate to page1.html but got ' + currentURL);
+			}
+
+			await page.goto(testURL);
+
+			// Test regex pattern - matches any page with .html extension
+			await Promise.all([
+				page.waitForNavigation({ url: /.*\.html$/ }),
+				page.locator('#page2').click()
+			]);
+			currentURL = page.url();
+			if (!currentURL.endsWith('.html')) {
+				throw new Error('Expected URL to end with .html but got ' + currentURL);
+			}
+
+			await page.goto(testURL);
+
+			// Test timeout when URL doesn't match
+			let timedOut = false;
+			try {
+				await Promise.all([
+					page.waitForNavigation({ url: /.*nonexistent.html$/, timeout: 500 }),
+					page.locator('#page1').click()  // This goes to page1.html, not nonexistent.html
+				]);
+			} catch (error) {
+				if (error.toString().includes('waiting for navigation')) {
+					timedOut = true;
+				} else {
+					throw error;
+				}
+			}
+			if (!timedOut) {
+				throw new Error('Expected timeout error when URL does not match');
+			}
+
+			await page.goto(testURL);
+
+			// Test empty pattern (matches any navigation)
+			await Promise.all([
+				page.waitForNavigation({ url: '' }),
+				page.locator('#page2').click()
+			]);
+			currentURL = page.url();
+			if (!currentURL.endsWith('page2.html')) {
+				throw new Error('Expected empty pattern to match any navigation but got ' + currentURL);
+			}
+		} finally {
+			// Must call close() which will clean up the taskqueue.
+			await page.close();
+		}
+	`,
+		tb.staticURL("waitfornavigation_test.html"),
+		tb.staticURL("page1.html"),
+	)
+	assert.Equal(t, sobek.Undefined(), got.Result())
+}
+
+func TestWaitForNavigationWithURL_RegexFailure(t *testing.T) {
+	t.Parallel()
+
+	tb := newTestBrowser(t, withFileServer())
+	tb.vu.ActivateVU()
+	tb.vu.StartIteration(t)
+
+	_, err := tb.vu.RunAsync(t, `
+		const page = await browser.newPage();
+		await page.goto('%s');
+
+		await Promise.all([
+			page.waitForNavigation({ url: /^.*/my_messages.*$/ }),
+			page.locator('#page2').click()
+		]);
+	`,
+		tb.staticURL("waitfornavigation_test.html"),
+	)
+	assert.ErrorContains(t, err, "Unexpected token *")
+}
+
+func TestWaitForURL(t *testing.T) {
+	if runtime.GOOS == "windows" {
+		t.Skip("Skipped due to https://github.com/grafana/k6/issues/4937")
+	}
+
+	t.Parallel()
+
+	tb := newTestBrowser(t, withFileServer())
+	tb.vu.ActivateVU()
+	tb.vu.StartIteration(t)
+
+	got := tb.vu.RunPromise(t, `
+		const page = await browser.newPage();
+		const testURL = '%s';
+
+		try {
+			// Test when already at matching URL (should just wait for load state)
+			await page.goto('%s');
+			await page.waitForURL(/.*page1\.html$/);
+			let currentURL = page.url();
+			if (!currentURL.endsWith('page1.html')) {
+				throw new Error('Expected to stay at page1.html but got ' + currentURL);
+			}
+
+			// Test exact URL match with navigation
+			await page.goto(testURL);
+			await Promise.all([
+				page.waitForURL('%s'),
+				page.locator('#page1').click()
+			]);
+			currentURL = page.url();
+			if (!currentURL.endsWith('page1.html')) {
+				throw new Error('Expected to navigate to page1.html but got ' + currentURL);
+			}
+
+			// Test regex pattern - matches any page with .html extension
+			await page.goto(testURL);
+			await Promise.all([
+				page.waitForURL(/.*\.html$/),
+				page.locator('#page2').click()
+			]);
+			currentURL = page.url();
+			if (!currentURL.endsWith('.html')) {
+				throw new Error('Expected URL to end with .html but got ' + currentURL);
+			}
+
+			// Test timeout when URL doesn't match
+			await page.goto(testURL);
+			let timedOut = false;
+			try {
+				await Promise.all([
+					page.waitForURL(/.*nonexistent\.html$/, { timeout: 500 }),
+					page.locator('#page1').click()  // This goes to page1.html, not nonexistent.html
+				]);
+			} catch (error) {
+				if (error.toString().includes('waiting for navigation')) {
+					timedOut = true;
+				} else {
+					throw error;
+				}
+			}
+			if (!timedOut) {
+				throw new Error('Expected timeout error when URL does not match');
+			}
+
+			// Test empty pattern (matches any navigation)
+			await page.goto(testURL);
+			await Promise.all([
+				page.waitForURL(''),
+				page.locator('#page2').click()
+			]);
+			currentURL = page.url();
+			if (!currentURL.endsWith('page2.html') && !currentURL.endsWith('waitfornavigation_test.html')) {
+				throw new Error('Expected empty pattern to match any navigation but got ' + currentURL);
+			}
+
+			// Test waitUntil option
+			await page.goto(testURL);
+			await Promise.all([
+				page.waitForURL(/.*page1\.html$/, { waitUntil: 'domcontentloaded' }),
+				page.locator('#page1').click()
+			]);
+			currentURL = page.url();
+			if (!currentURL.endsWith('page1.html')) {
+				throw new Error('Expected to navigate to page1.html with domcontentloaded but got ' + currentURL);
+			}
+
+			// Test when already at URL with regex pattern
+			await page.goto(testURL);
+			await page.waitForURL(/.*\/waitfornavigation_test\.html$/);
+			currentURL = page.url();
+			if (!currentURL.endsWith('waitfornavigation_test.html')) {
+				throw new Error('Expected to stay at waitfornavigation_test.html but got ' + currentURL);
+			}
+		} finally {
+			// Must call close() which will clean up the taskqueue.
+			await page.close();
+		}
+	`,
+		tb.staticURL("waitfornavigation_test.html"),
+		tb.staticURL("page1.html"),
+		tb.staticURL("page1.html"),
+	)
+	assert.Equal(t, sobek.Undefined(), got.Result())
+}
