@@ -8,7 +8,10 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"math"
+	"reflect"
 	"strings"
+	"sync"
 	"time"
 
 	"go.k6.io/k6/internal/lib/netext/grpcext"
@@ -36,6 +39,9 @@ type Client struct {
 	conn *grpcext.Conn
 	vu   modules.VU
 	addr string
+
+	types    *protoregistry.Types
+	typesMtx sync.Mutex
 }
 
 // Load will parse the given proto files and make the file descriptors available to request.
@@ -254,8 +260,12 @@ func (c *Client) Connect(addr string, params sobek.Value) (bool, error) {
 		opts = append(opts, grpc.WithDefaultCallOptions(grpc.MaxCallSendMsgSize(int(p.MaxSendSize))))
 	}
 
+	if p.Authority != "" {
+		opts = append(opts, grpc.WithAuthority(p.Authority))
+	}
+
 	c.addr = addr
-	c.conn, err = grpcext.Dial(ctx, addr, opts...)
+	c.conn, err = grpcext.Dial(ctx, addr, c.types, opts...)
 	if err != nil {
 		return false, err
 	}
@@ -278,6 +288,15 @@ func (c *Client) Connect(addr string, params sobek.Value) (bool, error) {
 	return true, err
 }
 
+// HealthCheck checks if the server side is up and ready to serve responses
+func (c *Client) HealthCheck(svc *string) (*grpcext.HealthCheckResponse, error) {
+	var service string
+	if svc != nil {
+		service = *svc
+	}
+	return c.conn.HealthCheck(c.vu.Context(), service)
+}
+
 // Invoke creates and calls a unary RPC by fully qualified method name
 func (c *Client) Invoke(
 	method string,
@@ -360,7 +379,16 @@ func (c *Client) buildInvokeRequest(
 	if req == nil {
 		return grpcReq, errors.New("request cannot be nil")
 	}
-	b, err := req.ToObject(c.vu.Runtime()).MarshalJSON()
+
+	object := req.ToObject(c.vu.Runtime())
+
+	var stack []*sobek.Object
+	normalized, err := normalizeNumberStrings(object, c.vu.Runtime(), stack)
+	if err != nil {
+		return grpcReq, fmt.Errorf("unable to normalize number strings: %w", err)
+	}
+
+	b, err := normalized.ToObject(c.vu.Runtime()).MarshalJSON()
 	if err != nil {
 		return grpcReq, fmt.Errorf("unable to serialise request object: %w", err)
 	}
@@ -378,6 +406,72 @@ func (c *Client) buildInvokeRequest(
 	}, nil
 }
 
+// normalizeNumberStrings recursively traverses a sobek.Value. It creates a deep copy of any
+// objects or arrays, and converts special float values (NaN, Infinity) to their
+// string representations for proper JSON serialization.
+func normalizeNumberStrings(v sobek.Value, runtime *sobek.Runtime, stack []*sobek.Object) (sobek.Value, error) {
+	// If v is a primitive (not an object or array), handle it directly.
+	if v == nil || sobek.IsNull(v) || sobek.IsUndefined(v) {
+		return v, nil
+	}
+
+	// Handle special float values.
+	if v.ExportType().Kind() == reflect.Float64 {
+		f := v.ToFloat()
+		switch {
+		case math.IsNaN(f):
+			return runtime.ToValue("NaN"), nil
+		case math.IsInf(f, 1):
+			return runtime.ToValue("Infinity"), nil
+		case math.IsInf(f, -1):
+			return runtime.ToValue("-Infinity"), nil
+		}
+
+		return v, nil
+	}
+
+	obj := v.ToObject(runtime)
+
+	// If it's not a real object (e.g., a string, bool, or regular number primitive),
+	// after checking for special floats, we can just return it.
+	// We use obj.ClassName() to distinguish real objects from primitive wrappers.
+	className := obj.ClassName()
+	if className != "Object" && className != "Array" {
+		return v, nil
+	}
+
+	// Similar to what's done when marshaling into JSON,
+	// detect and prevent infinite recursion due to circular object references.
+	for _, vis := range stack {
+		if obj.SameAs(vis) {
+			return nil, errors.New("cyclic reference to an object found")
+		}
+	}
+	stack = append(stack, obj)
+
+	// It's a real object or array, so we need to deep-copy and normalize it.
+	var newObj *sobek.Object
+	if className == "Array" {
+		newObj = runtime.NewArray()
+	} else {
+		newObj = runtime.NewObject()
+	}
+
+	for _, key := range obj.Keys() {
+		val := obj.Get(key)
+		normalizedVal, err := normalizeNumberStrings(val, runtime, stack)
+		if err != nil {
+			return nil, err
+		}
+
+		if err := newObj.Set(key, normalizedVal); err != nil {
+			return nil, err
+		}
+	}
+
+	return newObj, nil
+}
+
 // Close will close the client gRPC connection
 func (c *Client) Close() error {
 	if c.conn == nil {
@@ -426,6 +520,13 @@ func (c *Client) convertToMethodInfo(fdset *descriptorpb.FileDescriptorSet) ([]M
 			FullMethod: name,
 		})
 	}
+
+	// We want to avoid concurrent calls to client.load competing
+	// for registering types, as they may end up panicking if they
+	// try to register the same types.
+	c.typesMtx.Lock()
+	defer c.typesMtx.Unlock()
+
 	files.RangeFiles(func(fd protoreflect.FileDescriptor) bool {
 		sds := fd.Services()
 		for i := 0; i < sds.Len(); i++ {
@@ -448,9 +549,9 @@ func (c *Client) convertToMethodInfo(fdset *descriptorpb.FileDescriptorSet) ([]M
 			message := stack[len(stack)-1]
 			stack = stack[:len(stack)-1]
 
-			_, errFind := protoregistry.GlobalTypes.FindMessageByName(message.FullName())
+			_, errFind := c.types.FindMessageByName(message.FullName())
 			if errors.Is(errFind, protoregistry.NotFound) {
-				err = protoregistry.GlobalTypes.RegisterMessage(dynamicpb.NewMessageType(message))
+				err = c.types.RegisterMessage(dynamicpb.NewMessageType(message))
 				if err != nil {
 					return false
 				}
