@@ -6,6 +6,7 @@ import (
 	"time"
 
 	"github.com/stretchr/testify/require"
+
 	"go.k6.io/k6/js/modulestest"
 )
 
@@ -116,7 +117,7 @@ func TestSetIntervalOrder(t *testing.T) {
 				clearInterval(two);
 				clearInterval(three);
 				clearInterval(last);
-			}, 4);
+			}, 10);
 			var three = setInterval((_) => print("three"), 1);
 			print("outside");
 		`)
@@ -154,14 +155,25 @@ func TestSetTimeoutContextCancel(t *testing.T) {
 		}
 	}))
 
-	for i := 0; i < 2000; i++ {
+	for range 2000 {
 		ctx, cancel := context.WithCancel(context.Background())
 		runtime.CancelContext = cancel
 		runtime.VU.CtxField = ctx //nolint:fatcontext
 		runtime.VU.RuntimeField.ClearInterrupt()
 		const interruptMsg = "definitely an interrupt"
+		sync := make(chan struct{})
+		defer func() {
+			cancel()
+			<-sync
+		}()
 		go func() {
-			<-interruptChannel
+			defer close(sync)
+			select {
+			case <-interruptChannel:
+			case <-ctx.Done():
+				return
+			}
+
 			time.Sleep(time.Millisecond)
 			runtime.CancelContext()
 			runtime.VU.RuntimeField.Interrupt(interruptMsg)
