@@ -31,7 +31,7 @@ func TestExecutionSegmentEquals(t *testing.T) {
 	t.Run("To it's self", func(t *testing.T) {
 		t.Parallel()
 		es := stringToES(t, "1/2:2/3")
-		require.True(t, es.Equal(es))
+		require.True(t, es.Equal(es)) //nolint:gocritic
 	})
 }
 
@@ -87,7 +87,6 @@ func TestExecutionSegmentUnmarshalText(t *testing.T) {
 		// TODO add more strange or not so strange cases
 	}
 	for _, testCase := range testCases {
-		testCase := testCase
 		t.Run(testCase.input, func(t *testing.T) {
 			t.Parallel()
 			es := new(ExecutionSegment)
@@ -313,7 +312,6 @@ func TestExecutionSegmentSubSegment(t *testing.T) {
 	}
 
 	for _, testCase := range testCases {
-		testCase := testCase
 		t.Run(testCase.name, func(t *testing.T) {
 			t.Parallel()
 			require.Equal(t, testCase.result, testCase.base.SubSegment(testCase.sub))
@@ -356,7 +354,6 @@ func TestSegmentExecutionFloatLength(t *testing.T) {
 	}
 
 	for _, testCase := range testCases {
-		testCase := testCase
 		t.Run(testCase.es.String(), func(t *testing.T) {
 			t.Parallel()
 			require.InEpsilon(t, testCase.expected, testCase.es.FloatLength(), 0.001)
@@ -400,7 +397,6 @@ func TestExecutionSegmentStringSequences(t *testing.T) {
 	}
 
 	for _, tc := range testCases {
-		tc := tc
 		t.Run(tc.seq, func(t *testing.T) {
 			t.Parallel()
 			result, err := NewExecutionSegmentSequenceFromString(tc.seq)
@@ -422,6 +418,14 @@ func TestExecutionSegmentStringSequences(t *testing.T) {
 	}
 }
 
+func getTestRand(t testing.TB) *rand.Rand {
+	t.Helper()
+	seed := time.Now().UnixNano()
+	r := rand.New(rand.NewSource(seed)) //nolint:gosec
+	t.Logf("Random source seeded with %d\n", seed)
+	return r
+}
+
 // Return a randomly distributed sequence of n amount of
 // execution segments whose length totals 1.
 func generateRandomSequence(t testing.TB, n, m int64, r *rand.Rand) ExecutionSegmentSequence {
@@ -449,13 +453,11 @@ func generateRandomSequence(t testing.TB, n, m int64, r *rand.Rand) ExecutionSeg
 func TestExecutionSegmentScaleConsistency(t *testing.T) {
 	t.Parallel()
 
-	seed := time.Now().UnixNano()
-	r := rand.New(rand.NewSource(seed))
-	t.Logf("Random source seeded with %d\n", seed)
+	r := getTestRand(t)
 
 	const numTests = 10
 	for i := 0; i < numTests; i++ {
-		scale := rand.Int31n(99) + 2
+		scale := r.Int31n(99) + 2
 		seq := generateRandomSequence(t, r.Int63n(9)+2, 100, r)
 
 		t.Run(fmt.Sprintf("%d_%s", scale, seq), func(t *testing.T) {
@@ -474,13 +476,10 @@ func TestExecutionSegmentScaleConsistency(t *testing.T) {
 func TestExecutionTupleScaleConsistency(t *testing.T) {
 	t.Parallel()
 
-	seed := time.Now().UnixNano()
-	r := rand.New(rand.NewSource(seed))
-	t.Logf("Random source seeded with %d\n", seed)
-
+	r := getTestRand(t)
 	const numTests = 10
 	for i := 0; i < numTests; i++ {
-		scale := rand.Int31n(99) + 2
+		scale := r.Int31n(99) + 2
 		seq := generateRandomSequence(t, r.Int63n(9)+2, 200, r)
 
 		et, err := NewExecutionTuple(seq[0], &seq)
@@ -517,16 +516,14 @@ func TestExecutionSegmentScaleNoWobble(t *testing.T) {
 		requireSegmentScaleGreater(t, et)
 	})
 
-	seed := time.Now().UnixNano()
-	r := rand.New(rand.NewSource(seed))
-	t.Logf("Random source seeded with %d\n", seed)
+	r := getTestRand(t)
 
 	// Random segments
 	const numTests = 10
 	for i := 0; i < numTests; i++ {
 		seq := generateRandomSequence(t, r.Int63n(9)+2, 100, r)
 
-		es := seq[rand.Intn(len(seq))]
+		es := seq[r.Intn(len(seq))]
 
 		et, err := NewExecutionTuple(seq[0], &seq)
 		require.NoError(t, err)
@@ -573,7 +570,6 @@ func TestGetStripedOffsets(t *testing.T) {
 	}
 
 	for _, tc := range testCases {
-		tc := tc
 		t.Run(fmt.Sprintf("seq:%s;segment:%s", tc.seq, tc.seg), func(t *testing.T) {
 			t.Parallel()
 			ess, err := NewExecutionSegmentSequenceFromString(tc.seq)
@@ -610,7 +606,6 @@ func TestSequenceLCD(t *testing.T) {
 	}
 
 	for _, tc := range testCases {
-		tc := tc
 		t.Run(fmt.Sprintf("seq:%s", tc.seq), func(t *testing.T) {
 			t.Parallel()
 			ess, err := NewExecutionSegmentSequenceFromString(tc.seq)
@@ -623,10 +618,9 @@ func TestSequenceLCD(t *testing.T) {
 func BenchmarkGetStripedOffsets(b *testing.B) {
 	lengths := [...]int64{10, 100}
 	const seed = 777
-	r := rand.New(rand.NewSource(seed))
+	r := rand.New(rand.NewSource(seed)) //nolint:gosec
 
 	for _, length := range lengths {
-		length := length
 		b.Run(fmt.Sprintf("length%d,seed%d", length, seed), func(b *testing.B) {
 			sequence := generateRandomSequence(b, length, 100, r)
 			b.ResetTimer()
@@ -662,7 +656,6 @@ func BenchmarkGetStripedOffsetsEven(b *testing.B) {
 	}
 
 	for _, length := range lengths {
-		length := length
 		b.Run(fmt.Sprintf("length%d", length), func(b *testing.B) {
 			sequence := generateSequence(length)
 			b.ResetTimer()
@@ -690,7 +683,6 @@ func TestGetNewExecutionTupleBesedOnValue(t *testing.T) {
 	}
 
 	for _, tc := range testCases {
-		tc := tc
 		t.Run(fmt.Sprintf("seq:%s;segment:%s", tc.seq, tc.seg), func(t *testing.T) {
 			t.Parallel()
 			ess, err := NewExecutionSegmentSequenceFromString(tc.seq)
@@ -847,7 +839,6 @@ func TestNewExecutionTuple(t *testing.T) {
 	}
 
 	for _, testCase := range testCases {
-		testCase := testCase
 		t.Run(fmt.Sprintf("seg:'%s',seq:'%s'", testCase.seg, testCase.seq), func(t *testing.T) {
 			t.Parallel()
 			et, err := NewExecutionTuple(testCase.seg, testCase.seq)
@@ -887,7 +878,6 @@ func BenchmarkExecutionSegmentScale(b *testing.B) {
 	}
 
 	for _, tc := range testCases {
-		tc := tc
 		b.Run(fmt.Sprintf("seq:%s;segment:%s", tc.seq, tc.seg), func(b *testing.B) {
 			ess, err := NewExecutionSegmentSequenceFromString(tc.seq)
 			require.NoError(b, err)
@@ -899,7 +889,6 @@ func BenchmarkExecutionSegmentScale(b *testing.B) {
 			et, err := NewExecutionTuple(segment, &ess)
 			require.NoError(b, err)
 			for _, value := range []int64{5, 5523, 5000000, 67280421310721} {
-				value := value
 				b.Run(fmt.Sprintf("segment.Scale(%d)", value), func(b *testing.B) {
 					for i := 0; i < b.N; i++ {
 						segment.Scale(value)
