@@ -133,8 +133,6 @@ func TestThreshold_runNoTaint(t *testing.T) {
 	}
 
 	for _, testCase := range tests {
-		testCase := testCase
-
 		t.Run(testCase.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -192,7 +190,7 @@ func TestThresholdRun(t *testing.T) {
 		threshold := newThreshold(`rate<0.01`, false, types.NullDuration{})
 		threshold.parsed = parsed
 
-		t.Run("no taint", func(t *testing.T) {
+		t.Run("no taint", func(t *testing.T) { //nolint:paralleltest
 			b, err := threshold.runNoTaint(sinks)
 			assert.NoError(t, err)
 			assert.True(t, b)
@@ -218,14 +216,14 @@ func TestThresholdRun(t *testing.T) {
 		threshold := newThreshold(`rate<0.01`, false, types.NullDuration{})
 		threshold.parsed = parsed
 
-		t.Run("no taint", func(t *testing.T) {
+		t.Run("no taint", func(t *testing.T) { //nolint:paralleltest
 			b, err := threshold.runNoTaint(sinks)
 			assert.NoError(t, err)
 			assert.False(t, b)
 			assert.False(t, threshold.LastFailed)
 		})
 
-		t.Run("taint", func(t *testing.T) {
+		t.Run("taint", func(t *testing.T) { //nolint:paralleltest
 			b, err := threshold.run(sinks)
 			assert.NoError(t, err)
 			assert.False(t, b)
@@ -487,8 +485,6 @@ func TestThresholdsValidate(t *testing.T) {
 		}
 
 		for _, testCase := range tests {
-			testCase := testCase
-
 			t.Run(testCase.name, func(t *testing.T) {
 				t.Parallel()
 
@@ -603,7 +599,6 @@ func TestThresholdsRunAll(t *testing.T) {
 	}
 
 	for name, data := range testdata {
-		name, data := name, data
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 
@@ -733,8 +728,6 @@ func TestThresholdsRun(t *testing.T) {
 		},
 	}
 	for _, testCase := range tests {
-		testCase := testCase
-
 		t.Run(testCase.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -825,8 +818,6 @@ func TestThresholdsJSON(t *testing.T) {
 	}
 
 	for _, data := range testdata {
-		data := data
-
 		t.Run(data.JSON, func(t *testing.T) {
 			t.Parallel()
 
@@ -839,7 +830,7 @@ func TestThresholdsJSON(t *testing.T) {
 				assert.Equal(t, data.gracePeriod, ts.Thresholds[i].AbortGracePeriod)
 			}
 
-			t.Run("marshal", func(t *testing.T) {
+			t.Run("marshal", func(t *testing.T) { //nolint:paralleltest
 				data2, err := MarshalJSONWithoutHTMLEscape(ts)
 				assert.NoError(t, err)
 				output := data.JSON
